@@ -18,7 +18,7 @@ class OffAmazonPayments(MWS):
                 TransactionTimeout=str(timeout),
                 **{
                     "AuthorizationAmount.Amount": "{:.2f}".format(order_total),
-                    "AuthorizationAmount.CurrencyCode": "USD"
+                    "AuthorizationAmount.CurrencyCode": "USD",
                 }
             )
         )
@@ -26,8 +26,7 @@ class OffAmazonPayments(MWS):
     def get_authorization_status(self, auth_id):
         return self.make_request(
             extra_data=dict(
-                Action="GetAuthorizationDetails",
-                AmazonAuthorizationId=auth_id
+                Action="GetAuthorizationDetails", AmazonAuthorizationId=auth_id
             )
         )
 
@@ -54,10 +53,7 @@ class OffAmazonPayments(MWS):
 
     def get_capture_details(self, capture_id):
         return self.make_request(
-            extra_data=dict(
-                Action="GetCaptureDetails",
-                AmazonCaptureId=capture_id
-            )
+            extra_data=dict(Action="GetCaptureDetails", AmazonCaptureId=capture_id)
         )
 
     def close_authorization(self, auth_id):
@@ -66,10 +62,7 @@ class OffAmazonPayments(MWS):
         the authorization has been captured.
         """
         return self.make_request(
-            extra_data=dict(
-                Action="CloseAuthorization",
-                AmazonAuthorizationId=auth_id
-            )
+            extra_data=dict(Action="CloseAuthorization", AmazonAuthorizationId=auth_id)
         )
 
     def refund(self, capture_id, amount, refund_id, notes="", currency="USD"):
@@ -90,7 +83,7 @@ class OffAmazonPayments(MWS):
                 SellerRefundNote=notes,
                 **{
                     "RefundAmount.Amount": "{:.2f}".format(amount),
-                    "RefundAmount.CurrencyCode": currency
+                    "RefundAmount.CurrencyCode": currency,
                 }
             )
         )
@@ -102,27 +95,22 @@ class OffAmazonPayments(MWS):
         you can call this operation to get the current status.
         """
         return self.make_request(
-            extra_data=dict(
-                Action="GetRefundDetails",
-                AmazonRefundId=refund_id
-            )
+            extra_data=dict(Action="GetRefundDetails", AmazonRefundId=refund_id)
         )
 
-    def get_billing_agreement_details(self, order_ref,
-                                      address_consent_token):
+    def get_billing_agreement_details(self, order_ref, address_consent_token):
         return self.make_request(
             extra_data=dict(
                 Action="GetBillingAgreementDetails",
                 AmazonBillingAgreementId=order_ref,
-                AddressConsentToken=address_consent_token
+                AddressConsentToken=address_consent_token,
             )
         )
 
-    def get_order_reference_details(self, order_ref,
-                                    address_consent_token=""):
+    def get_order_reference_details(self, order_ref, address_consent_token=""):
         kwargs = {}
         if address_consent_token:
-            kwargs['AddressConsentToken'] = address_consent_token
+            kwargs["AddressConsentToken"] = address_consent_token
 
         return self.make_request(
             extra_data=dict(
@@ -132,13 +120,21 @@ class OffAmazonPayments(MWS):
             )
         )
 
-    def set_order_reference_details(self, order_ref, order_total,
-                                    store_name, order_id=None, note=None, currency="USD"):
+    def set_order_reference_details(
+        self,
+        order_ref,
+        order_total,
+        store_name,
+        order_id=None,
+        note=None,
+        currency="USD",
+    ):
         params = {
             "OrderReferenceAttributes.OrderTotal.Amount": str(order_total),
             "OrderReferenceAttributes.OrderTotal.CurrencyCode": currency,
             "OrderReferenceAttributes.SellerOrderAttributes.SellerOrderId": str(
-                order_id),
+                order_id
+            ),
             "OrderReferenceAttributes.SellerOrderAttributes.StoreName": store_name,
             "OrderReferenceAttributes.SellerNote": note,
         }
@@ -162,15 +158,13 @@ class OffAmazonPayments(MWS):
     def cancel_order_reference(self, order_ref):
         return self.make_request(
             extra_data=dict(
-                Action="CancelOrderReference",
-                AmazonOrderReferenceId=order_ref
+                Action="CancelOrderReference", AmazonOrderReferenceId=order_ref
             )
         )
 
     def close_order_reference(self, order_ref):
         return self.make_request(
             extra_data=dict(
-                Action="CloseOrderReference",
-                AmazonOrderReferenceId=order_ref
+                Action="CloseOrderReference", AmazonOrderReferenceId=order_ref
             )
         )
